@@ -1,14 +1,15 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.014-8-g10b6654
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.016-7-g1d7c6e6
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.015';
+our $VERSION = '0.017';
 
 use Moose;
-with 'Dist::Zilla::Role::MetaProvider';
+with 'Dist::Zilla::Role::MetaProvider',
+    'Dist::Zilla::Role::PrereqSource';
 
 use List::Util 1.33 'none';
 use Git::Wrapper 0.035;
@@ -17,6 +18,7 @@ use Path::Tiny 0.048;
 use Moose::Util::TypeConstraints 'enum';
 use List::UtilsBy 0.04 'uniq_by';
 use Unicode::Collate 0.53;
+use version;
 use namespace::autoclean;
 
 sub mvp_multivalue_args { qw(paths remove) }
@@ -86,7 +88,45 @@ sub metadata
     +{ x_contributors => $contributors };
 }
 
-sub _contributors
+sub register_prereqs
+{
+    my $self = shift;
+
+    return if none { /[^[:ascii:]]/ } @{$self->_contributors};
+
+    my $prereqs = $self->zilla->prereqs;
+    my $perl_prereq = $prereqs->requirements_for(qw(runtime requires))
+        ->clone
+        ->add_requirements($prereqs->requirements_for(qw(configure requires)))
+        ->add_requirements($prereqs->requirements_for(qw(build requires)))
+        ->add_requirements($prereqs->requirements_for(qw(test requires)))
+        ->as_string_hash->{perl};
+
+    $self->log_debug([ 'found non-ascii characters in contributor names; perl prereq so far is %s',
+        defined $perl_prereq ? $perl_prereq : 'unknown' ]);
+    $perl_prereq = 0 if not defined $perl_prereq;
+    $perl_prereq = version->parse($perl_prereq)->numify;
+    return if "$perl_prereq" >= '5.008006';
+
+    # see https://github.com/makamaka/JSON-PP/pull/9 for for details
+    $self->log_debug('injecting JSON::PP prereq to deal with non-ascii content in META.json');
+    $self->zilla->register_prereqs(
+        {
+            phase => 'runtime',
+            type  => 'requires',
+        },
+        'JSON::PP' => '2.27300',
+    );
+}
+
+# should not be called before the MetaProvider phase
+has _contributors => (
+    is => 'ro', isa => 'ArrayRef[Str]',
+    lazy => 1,
+    builder => '_build_contributors',
+);
+
+sub _build_contributors
 {
     my $self = shift;
 
@@ -209,7 +249,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.015
+version 0.017
 
 =head1 SYNOPSIS
 
@@ -329,7 +369,7 @@ L<Module::Install::Contributors>
 
 =back
 
-=for Pod::Coverage mvp_multivalue_args mvp_aliases metadata
+=for Pod::Coverage mvp_multivalue_args mvp_aliases metadata register_prereqs
 
 =head1 SUPPORT
 
@@ -340,7 +380,7 @@ There is also a mailing list available for users of this distribution, at
 L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-irc://irc.perl.org/#distzilla.
+L<irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
